UI
==

.. currentmodule:: QuadratiK.ui

.. autoclass:: UI

.. rubric:: Methods

.. autosummary::
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
        UI.main
    
    
    
        UI.run
    
    

----





.. automethod:: UI.main



.. automethod:: UI.run



.. raw:: html

     <div style='clear:both'></div>